@@ -5,7 +5,7 @@ use std::path::Path;
 use std::pin::Pin;
 use std::task::{Context, Poll};
 
-use futures_util::io::{AsyncRead, AsyncWrite, IoSlice, IoSliceMut};
+use futures_io::{AsyncRead, AsyncWrite, IoSlice, IoSliceMut};
 use socket2::{Domain, SockAddr, Socket, Type};
 
 use crate::io::Async;
